@@ -2,10 +2,8 @@ from .connection_types import ConnectionType
 from .context import GlueContextOptions, GluePySparkContext
 from .formats import Format
 from .job import GluePySparkJob
-from .options import BaseOptions
 
 __all__ = [
-    "BaseOptions",
     "ConnectionType",
     "Format",
     "GlueContextOptions",
